-- List of stylesheets that are added to newly created docs.  Without
-- a full path, stylesheets are searched for in the standard style
-- directory.
prefs.styles = { "presentation", "decorations", "jens" }

-- Where the tools should be placed (left or right)
-- and which ones should be displayed on start-up
-- tools_placement is only used with Qt toolkit
prefs.tools_visible = {
  properties = true,
  bookmarks = true,
  notes = true,
  layers = true
}

-- on Windows, initial ordering of the toolbars
prefs.win_toolbar_order = { "edit", "mode", "grid", "angle", "snap" }

-- Minimum size of dialog window for creating/editing text objects
prefs.editor_size = { 1000, 500 }

-- Size of main window at startup
prefs.window_size = { 1920, 1080 }
-- Size of Latex error message window
prefs.latexlog_size = { 1920, 1080 }

-- Snap modes active when Ipe starts:
prefs.snap = { vertex = true,
	       ctrlpoints = true,
	       boundary = false,
	       intersection = true,
	       grid = true,
	       angle = false,
	       custom = false,
	       autoangle = false }

-- UI settings when Ipe starts
prefs.initial = {
  grid_size = 8,     -- points
  angle_size = 45,    -- degrees
  grid_visible = true,
}

-- Attributes set when Ipe starts
prefs.initial_attributes = {
  pathmode = "stroked",
  stroke = "black",
  fill = "white",
  pen = "normal",
  dashstyle = "normal",
  farrowshape = "arrow/normal(spx)",
  rarrowshape = "arrow/normal(spx)",
  farrowsize = "tiny",
  rarrowsize = "tiny",
  farrow = false,
  rarrow = false,
  symbolsize = "normal",
  textsize = "normal",
  textstyle = "normal",
  transformabletext = false,
  splinetype = "bspline",
  horizontalalignment = "left",
  verticalalignment = "vcenter",
  pinned = "none",
  transformations = "affine",
  linejoin = "normal",
  linecap = "round",
  fillrule = "normal",
  markshape = "mark/fdisk(sfx)",
  tiling = "normal",
  gradient = "normal",
  opacity = "opaque",
  strokeopacity = "opaque",
}

-- If set to true, then whenever the user edits the title of a page,
-- the check box "section: use title" is checked automatically.
prefs.automatic_use_title = true

-- Auto-exporting when document is being saved
-- If this is set, then every time you save in xml format, say to
-- mydoc.ipe, the same document is EXPORTED to mydoc.format,
-- for each of the enabled formats.
-- Careful: if the file exists, it is silently overwritten.
-- The exported files cannot be opened by Ipe (they are exported copies).
-- Export to eps, png, svg use the first view of the first page only.
-- possible formats are "pdf", "eps", "svg", "png"
-- e.g. prefs.auto_export = { "pdf", "eps" }
prefs.auto_export = { "pdf" }

-- Maximum distance in pixels selecting/snapping
prefs.select_distance = 18
prefs.snap_distance = 8
-- When transforming objects, if currently select object is further than
-- this distance, the closest object is selected instead
prefs.close_distance = 24

-- If set to true, then whenever the user edits the title of a page,
-- the check box "section: use title" is checked automatically.
prefs.automatic_use_title = true

-- Default directory for "Save as" dialog, when
-- the current document does not have a filename
-- (or the filename is not absolute)
if config.platform == "win" then
  -- Another reasonable setting: config.desktop
  prefs.save_as_directory = "c:\\copy"
else
  -- If you use Ipe from the commandline, "." is the right value.
  -- Otherwise, you could use the home directory
  prefs.save_as_directory = "."
  -- prefs.save_as_directory = home
end

-- Available actions are:
-- "select"
-- "translate", "rotate", "stretch",
-- "scale" (like "stretch" with Shift)
-- "pan"
-- "menu" (opens context menu)
-- "shredder" (erases object closest to mouse)
-- or write a Lua function with arguments (model, modifiers)
-- left and left_shift cannot be remapped
-- More than two modifiers are possible in the order
-- shift_control_alt_meta
-- e.g. left_shift_meta = "rotate"
-- If your mouse has additional buttons, then you can also use
-- button8, button9, and button10.
-- (It seems other buttons are not passed through by Qt.)
mouse = {
  left_alt = "translate",
  left_control = "select",
  left_shift_control = "select",
  middle = "pan",
  right = "menu",
  right_alt = "rotate",
  right_control = "stretch",
  right_shift_control = "scale",
  right_shift = "pan",
  button10 = "translate",
}